from setuptools import setup, find_packages

setup(
    name="ai-search-api",
    version="0.0.8.2.9.1",
    packages=find_packages(),
    install_requires=[],
    description="search the future [test version]",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author="NeopadAI",
    author_email="neopad.azienda@gmail.com",
    url="https://github.com/neopad/ai-search",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)